from .pysdbots import *

__version__ = "0.1.1"


__all__ = [
    "anime_logo",
    "tiktok",
    "apod",
    "detect_lang",
    "write",
    "chk",
    "sk_checker",
    "lyrics",
    "ipinfo",
    "hirunews",
    "logohq",
    "fakeinfo",
]

